Documentation
¶
Overview ¶
A Golang library to open objects (URL, Directoris, Files, Images, Videos) using OS's pefered application for that object type. The whole library is adapted from https://github.com/openfl/lime/blob/develop/src/lime/system/System.hx#L423
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Open ¶
Open opens the object using OS's pefered application for that object type. If the object type is somthing other then a URL it should be absolute path to the object.
func OpenStream ¶
OpenStream writes content of r into a file created in OS's tempory directory. If extension is not empty, extension is added to the end of the tempory file, file with no extension is up to OS to handle and file get opened by OS's pefered way. Then OpenStream returns the filepath of the tempory file created and an error. If there were any error returned filepath may be empty.